@@ -1,5 +1,5 @@
 package Pushmi::Apache::AuthCommit;
-
+# XXX: make this a subclass of relayprovider
 use strict;
 use warnings;
 
@@ -35,7 +35,7 @@ sub handler {
 
         # XXX: use stdin or setproctitle
         # XXX: log $!
-        system(   "$pushmi mirror $repospath --tryauth '"
+        system(   "$pushmi tryauth $repospath '"
                 . $r->user
                 . "' '$password'" );
 
